@@ -1,11 +1,11 @@
 ;;; easy-hugo.el --- Write blogs made with hugo by markdown or org-mode -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2017-2025 by Masashi Miyaura
+;; Copyright (C) 2017-2026 by Masashi Miyaura
 
 ;; Author: Masashi Miyaura
 ;; URL: https://github.com/masasam/emacs-easy-hugo
-;; Package-Version: 20250908.2343
-;; Package-Revision: ee4a6d2ee65d
+;; Package-Version: 20260112.502
+;; Package-Revision: f39adb614ce2
 ;; Package-Requires: ((emacs "25.1") (request "0.3.0") (transient "0.3.6"))
 
 ;; This program is free software; you can redistribute it and/or modify
@@ -221,11 +221,6 @@ Because only two are supported by hugo."
   :group 'easy-hugo
   :type 'integer)
 
-(defcustom easy-hugo-org-header nil
-  "Flg of use in org format header with hugo version 0.25 and above."
-  :group 'easy-hugo
-  :type 'integer)
-
 (defvar easy-hugo--preview-loop t
   "Preview loop flg.")
 
@@ -256,12 +251,21 @@ Because only two are supported by hugo."
 (defconst easy-hugo--preview-buffer "*Hugo Preview*"
   "Easy-hugo preview buffer name.")
 
+(defconst easy-hugo--org-extension "org"
+  "Default org extension value, only supported variant.")
+
+(defconst easy-hugo--rst-extension "rst"
+  "Default rst extension value, only supported variant.")
+
+(defconst easy-hugo--mmark-extension "mmark"
+  "Default mmark extension value, only supported variant.")
+
 (defconst easy-hugo--formats `(,easy-hugo-markdown-extension
-			       "org"
-			       ,easy-hugo-asciidoc-extension
-			       "rst"
-			       "mmark"
-			       ,easy-hugo-html-extension))
+			                   ,easy-hugo--org-extension
+			                   ,easy-hugo-asciidoc-extension
+			                   ,easy-hugo--rst-extension
+			                   ,easy-hugo--mmark-extension
+			                   ,easy-hugo-html-extension))
 
 (defface easy-hugo-help-face
   `((((class color) (background light))
@@ -885,58 +889,35 @@ Automatically select the deployment destination from init.el."
       (browse-url (easy-hugo-nth-eval-bloglist easy-hugo-url n)))
     (setf (nth n easy-hugo--firebase-deploy-timer-list) nil)))
 
-(defun easy-hugo--org-headers (file)
-  "Return a draft org mode header string for a new article as FILE."
-  (let ((datetimezone
-         (concat
-          (format-time-string "%Y-%m-%dT%T")
-          (easy-hugo--orgtime-format (format-time-string "%z")))))
-    (concat
-     "#+TITLE: " file
-     "\n#+DATE: " datetimezone
-     "\n#+DRAFT: nil"
-     "\n#+CATEGORIES[]: nil nil"
-     "\n#+TAGS[]: nil nil"
-     "\n#+DESCRIPTION: Short description"
-     "\n\n")))
 
 ;;;###autoload
 (defun easy-hugo-newpost (post-file)
   "Create a new post with hugo.
-POST-FILE needs to have and extension '.md' or '.org' or '.ad' or
-'.rst' or '.mmark' or '.html'."
+POST-FILE needs to have an extension '.md', '.org', '.ad', '.rst',
+'.mmark', or '.html'."
   (interactive (list (read-from-minibuffer
-		      "Filename: "
-		      `(,easy-hugo-default-ext . 1) nil nil nil)))
+                      "Filename: "
+                      `(,easy-hugo-default-ext . 1) nil nil nil)))
   (easy-hugo-with-env
    (let ((filename (expand-file-name post-file easy-hugo-postdir))
-	 (file-ext (file-name-extension post-file)))
+         (file-ext (file-name-extension post-file)))
      (when (not (member file-ext easy-hugo--formats))
-       (error "Please enter .%s or .org or .%s or .rst or .mmark or .%s file name"
-	      easy-hugo-markdown-extension
-	      easy-hugo-asciidoc-extension
-	      easy-hugo-html-extension))
+       (error "Please enter .%s, .%s, .%s, .%s, .%s, or .%s file name"
+              easy-hugo-markdown-extension
+              easy-hugo--org-extension
+              easy-hugo-asciidoc-extension
+              easy-hugo--rst-extension
+              easy-hugo--mmark-extension
+              easy-hugo-html-extension))
      (when (file-exists-p (file-truename filename))
        (error "%s already exists!" filename))
-     (if (null easy-hugo-org-header)
-	 (call-process easy-hugo-bin nil "*hugo*" t "new"
-		       (file-relative-name filename
-					   (expand-file-name "content" easy-hugo-basedir)))
-       (progn
-	 (if (or (string-equal file-ext easy-hugo-markdown-extension)
-		 (string-equal file-ext easy-hugo-asciidoc-extension)
-		 (string-equal file-ext "rst")
-		 (string-equal file-ext "mmark")
-		 (string-equal file-ext easy-hugo-html-extension))
-	     (call-process easy-hugo-bin nil "*hugo*" t "new"
-			   (file-relative-name filename
-					       (expand-file-name "content" easy-hugo-basedir))))))
+     (call-process
+      easy-hugo-bin nil "*hugo*" t "new"
+      (file-relative-name filename
+                          (expand-file-name "content" easy-hugo-basedir)))
      (when (get-buffer "*hugo*")
        (kill-buffer "*hugo*"))
      (find-file filename)
-     (when (and easy-hugo-org-header
-	       (string-equal file-ext "org"))
-       (insert (easy-hugo--org-headers (file-name-base post-file))))
      (goto-char (point-max))
      (save-buffer))))
 
@@ -1832,8 +1813,13 @@ Optional prefix ARG says how many lines to move; default is one line."
    (let ((newname (expand-file-name post-file easy-hugo-postdir))
 	 (file-ext (file-name-extension post-file)))
      (when (not (member file-ext easy-hugo--formats))
-       (error "Please enter .%s or .org or .%s or .rst or .mmark or .%s file name"
-	      easy-hugo-markdown-extension easy-hugo-asciidoc-extension easy-hugo-html-extension))
+       (error "Please enter .%s, .%s, .%s, .%s, .%s, or .%s file name"
+	      easy-hugo-markdown-extension
+          easy-hugo--org-extension
+          easy-hugo-asciidoc-extension
+          easy-hugo--rst-extension
+          easy-hugo--mmark-extension
+          easy-hugo-html-extension))
      (when (equal (buffer-name (current-buffer)) easy-hugo--buffer-name)
        (when (file-exists-p (file-truename newname))
 	 (error "%s already exists!" newname))
@@ -2353,13 +2339,14 @@ output directories whose names match REGEXP."
 	 (lists (list))
 	 (files (list)))
      (dolist (file source)
-       (if (equal (file-relative-name easy-hugo-postdir "content") ".")
+       (if (and (equal (file-relative-name easy-hugo-postdir "content") ".")
+				(not (equal (file-name-nondirectory easy-hugo-postdir) "content")))
 	   (when (eq (string-match "\\([^/]+\\)$" file) 0)
 	     (push (match-string 1 file) files))
 	 (when (string-match
 		(concat (file-relative-name easy-hugo-postdir "content") "/\\(.+?\\)$")
 		file)
-	   (push (match-string 1 file) files))))
+	   (push (car (string-split (match-string 1 file) ",")) files))))
      (unless (file-directory-p (expand-file-name easy-hugo-postdir easy-hugo-basedir))
        (error "%s%s does not exist!" easy-hugo-basedir easy-hugo-postdir))
      (setq easy-hugo--mode-buffer (get-buffer-create easy-hugo--buffer-name))
